@@ -1,6 +1,4 @@
-
 package HTML::Parse;
-  # Time-stamp: "1999-12-20 12:11:34 MST"
 
 =head1 NAME
 
@@ -86,27 +84,35 @@ L<HTML::Parser>, L<HTML::TreeBuilder>, L<HTML::Element>
 
 =head1 COPYRIGHT
 
-Copyright 1995-1998 Gisle Aas. All rights reserved.
+Copyright 1995-1998 Gisle Aas, 1999-2004 Sean M. Burke, 2005 Andy Lester,
+2006 Pete Krawczyk.
 
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
+This program is distributed in the hope that it will be useful, but
+without any warranty; without even the implied warranty of
+merchantability or fitness for a particular purpose.
+
 =head1 AUTHOR
 
-Gisle Aas E<lt>gisle@aas.noE<gt>
+Currently maintained by Pete Krawczyk C<< <petek@cpan.org> >>
+
+Original authors: Gisle Aas, Sean Burke and Andy Lester.
 
 =cut
 
+use warnings;
+use strict;
+
+use vars qw(@ISA $VERSION @EXPORT
+    $IMPLICIT_TAGS $IGNORE_UNKNOWN $IGNORE_TEXT $WARN
+);
 
 require Exporter;
-@ISA = qw(Exporter);
+@ISA    = qw(Exporter);
 @EXPORT = qw(parse_html parse_htmlfile);
 
-use strict;
-use vars qw($VERSION
-            $IMPLICIT_TAGS $IGNORE_UNKNOWN $IGNORE_TEXT $WARN
-           );
-
 # Backwards compatability
 $IMPLICIT_TAGS  = 1;
 $IGNORE_UNKNOWN = 1;
@@ -115,33 +121,28 @@ $WARN           = 0;
 
 require HTML::TreeBuilder;
 
-$VERSION = '2.7';
+$VERSION = '2.71';
 
-
-sub parse_html ($;$)
-{
+sub parse_html {
     my $p = $_[1];
     $p = _new_tree_maker() unless $p;
-    $p->parse($_[0]);
+    $p->parse( $_[0] );
 }
 
-
-sub parse_htmlfile ($;$)
-{
-    my($file, $p) = @_;
-    local(*HTML);
-    open(HTML, $file) or return undef;
+sub parse_htmlfile {
+    my ( $file, $p ) = @_;
+    my ($HTML);
+    open( $HTML, "<", $file ) or return;
     $p = _new_tree_maker() unless $p;
-    $p->parse_file(\*HTML);
+    $p->parse_file($HTML);
 }
 
-sub _new_tree_maker
-{
+sub _new_tree_maker {
     my $p = HTML::TreeBuilder->new(
-      implicit_tags  => $IMPLICIT_TAGS,
-      ignore_unknown => $IGNORE_UNKNOWN,
-      ignore_text    => $IGNORE_TEXT,
-      'warn'         => $WARN,
+        implicit_tags  => $IMPLICIT_TAGS,
+        ignore_unknown => $IGNORE_UNKNOWN,
+        ignore_text    => $IGNORE_TEXT,
+        'warn'         => $WARN,
     );
     $p->strict_comment(1);
     $p;
